// This file was generated by [ts-rs](https://github.com/Aleph-Alpha/ts-rs). Do not edit this file manually.
import type { FontGroup } from "./FontGroup";

export interface FontScheme { majorFont: FontGroup, minorFont: FontGroup, }