// This file was generated by [ts-rs](https://github.com/Aleph-Alpha/ts-rs). Do not edit this file manually.
import type { FontScheme } from "./FontScheme";

export interface Theme { fontSchema: FontScheme, }